# Near field imager and simulator for radio interferometers

nfis is a Python-based tool for performing near field imaging and simulations on radio interferometric measurement sets. The imaging and simulation algorithms are described in Munshi et al. 2025 (in prep).

# Dependencies
nfis requires some common python libraries: numpy, matplotlib, astropy.

# Installation
nfis can be installed via pip:
```
pip install nfis
```

# Documentation
A step-by-step guide is presented in the wiki page.
